@@ -14,7 +14,7 @@ for cat in $catalogs; do
   lang=`echo $cat | sed 's/\.po$//'`
   mv $cat $lang.old.po
   echo "$lang:"
-  if msgmerge $lang.old.po templates.pot -o $cat; then
+  if msgmerge --previous $lang.old.po templates.pot -o $cat; then
     rm -f $lang.old.po
   else
     echo "msgmerge for $cat failed!"
